<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns="http://www.w3.org/1999/xhtml"
                              xmlns:html="http://www.w3.org/1999/xhtml"
                              xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                              xmlns:msxsl="urn:schemas-microsoft-com:xslt"
                              xmlns:wwmode="urn:WebWorks-Engine-Mode"
                              xmlns:wwlinks="urn:WebWorks-Engine-Links-Schema"
                              xmlns:wwfiles="urn:WebWorks-Engine-Files-Schema"
                              xmlns:wwdoc="urn:WebWorks-Document-Schema"
                              xmlns:wwsplits="urn:WebWorks-Engine-Splits-Schema"
                              xmlns:wwtoc="urn:WebWorks-Engine-TOC-Schema"
                              xmlns:wwbehaviors="urn:WebWorks-Behaviors-Schema"
                              xmlns:wwnotes="urn:WebWorks-Footnote-Schema"
                              xmlns:wwproject="urn:WebWorks-Publish-Project"
                              xmlns:wwpage="urn:WebWorks-Page-Template-Schema"
                              xmlns:wwlocale="urn:WebWorks-Locale-Schema"
                              xmlns:wwprogress="urn:WebWorks-XSLT-Extension-Progress"
                              xmlns:wwlog="urn:WebWorks-XSLT-Extension-Log"
                              xmlns:wwfilesystem="urn:WebWorks-XSLT-Extension-FileSystem"
                              xmlns:wwuri="urn:WebWorks-XSLT-Extension-URI"
                              xmlns:wwstring="urn:WebWorks-XSLT-Extension-StringUtilities"
                              xmlns:wwunits="urn:WebWorks-XSLT-Extension-Units"
                              xmlns:wwfilesext="urn:WebWorks-XSLT-Extension-Files"
                              xmlns:wwprojext="urn:WebWorks-XSLT-Extension-Project"
                              xmlns:wwimaging="urn:WebWorks-XSLT-Extension-Imaging"
                              xmlns:wwexsldoc="urn:WebWorks-XSLT-Extension-Document"
                              xmlns:wwdatetime="urn:WebWorks-Date-Time-Extension"
                              exclude-result-prefixes="xsl msxsl wwmode wwlinks wwfiles wwdoc wwsplits wwtoc wwbehaviors wwnotes wwproject wwpage wwlocale wwprogress wwlog wwfilesystem wwuri wwstring wwunits wwfilesext wwprojext wwimaging wwexsldoc wwdatetime"
>
 <xsl:key name="wwbehaviors-meta-by-name" match="wwbehaviors:META" use="@name" />


 <xsl:template name="METAMarkers-Conditions">
  <xsl:param name="ParamBehaviors" />
  <xsl:param name="ParamSplit" />

  <xsl:variable name="VarMETADocumentMarkers" select="$ParamBehaviors//wwbehaviors:Marker[@behavior = 'meta-document']/wwdoc:Marker" />
  <xsl:variable name="VarMETASplitMarkers" select="$ParamBehaviors/wwbehaviors:Behaviors/wwbehaviors:Split[@id = $ParamSplit/@id]//wwbehaviors:Marker[@behavior = 'meta-split']/wwdoc:Marker" />
  <xsl:variable name="VarMETAMarkers" select="$VarMETADocumentMarkers | $VarMETASplitMarkers" />

  <xsl:if test="count($VarMETAMarkers[1]) > 0">
   <wwpage:Condition name="meta-markers-exist" />
  </xsl:if>
 </xsl:template>


 <xsl:template name="METAMarkers-Replacements">
  <xsl:param name="ParamBehaviors" />
  <xsl:param name="ParamSplit" />

  <xsl:variable name="VarMETADocumentMarkers" select="$ParamBehaviors//wwbehaviors:Marker[@behavior = 'meta-document']/wwdoc:Marker" />
  <xsl:variable name="VarMETASplitMarkers" select="$ParamBehaviors/wwbehaviors:Behaviors/wwbehaviors:Split[@id = $ParamSplit/@id]//wwbehaviors:Marker[@behavior = 'meta-split']/wwdoc:Marker" />
  <xsl:variable name="VarMETAMarkers" select="$VarMETADocumentMarkers | $VarMETASplitMarkers" />

  <!-- All META tag names -->
  <!--                    -->
  <xsl:variable name="VarMETATagNamesAsXML">
   <xsl:for-each select="$VarMETAMarkers">
    <xsl:variable name="VarMETAMarker" select="." />

    <wwbehaviors:META name="{$VarMETAMarker/@name}" />
   </xsl:for-each>
  </xsl:variable>
  <xsl:variable name="VarMETATagNames" select="msxsl:node-set($VarMETATagNamesAsXML)/*" />

  <!-- Unique META tag names -->
  <!--                       -->
  <xsl:variable name="VarUniqueMETATagNamesAsXML">
   <xsl:for-each select="$VarMETATagNames">
    <xsl:variable name="VarMETATagName" select="." />

    <!-- Take first unique entry -->
    <!--                         -->
    <xsl:if test="count($VarMETATagName | key('wwbehaviors-meta-by-name', $VarMETATagName/@name)[1]) = 1">
     <xsl:copy-of select="$VarMETATagName" />
    </xsl:if>
   </xsl:for-each>
  </xsl:variable>
  <xsl:variable name="VarUniqueMETATagNames" select="msxsl:node-set($VarUniqueMETATagNamesAsXML)/*" />

  <wwpage:Replacement name="meta-markers">
   <xsl:for-each select="$VarUniqueMETATagNames">
    <xsl:variable name="VarMETATagName" select="." />

    <!-- Define the META tag content -->
    <!--                             -->
    <xsl:variable name="VarMETATagContent">
     <xsl:for-each select="$VarMETAMarkers[@name = $VarMETATagName/@name]">
      <xsl:variable name="VarMETAMarker" select="." />

      <xsl:for-each select="$VarMETAMarker/wwdoc:TextRun/wwdoc:Text">
       <xsl:variable name="VarText" select="." />

       <xsl:value-of select="$VarText/@value" />
      </xsl:for-each>

      <xsl:if test="position() &lt; last()">
       <xsl:text>,</xsl:text>
      </xsl:if>
     </xsl:for-each>
    </xsl:variable>

    <html:meta name="{$VarMETATagName/@name}" content="{$VarMETATagContent}" />
   </xsl:for-each>
  </wwpage:Replacement>
 </xsl:template>
</xsl:stylesheet>
